package com.muyu.etl.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.etl.domain.BasicConfigInfo;
import com.muyu.etl.domain.resp.BasicConfigResp;
import com.muyu.etl.service.BasicConfigInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 基础信息Controller
 *
 * @author muyu
 * @date 2024-04-21
 */
@RestController
@RequestMapping("/info")
public class BasicConfigInfoController extends BaseController
{
    @Autowired
    private BasicConfigInfoService basicConfigInfoService;

    /**
     * 查询基础信息列表
     */
    @RequiresPermissions("etl:info:list")
    @GetMapping("/list")
    public Result<TableDataInfo<BasicConfigResp>> list(BasicConfigInfo basicConfigInfo)
    {
        startPage();
        List<BasicConfigResp> list = basicConfigInfoService.selectBasicConfigInfoList(basicConfigInfo);
        return getDataTable(list);
    }

    /**
     * 导出基础信息列表
     */
    @RequiresPermissions("etl:info:export")
    @Log(title = "基础信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicConfigInfo basicConfigInfo)
    {
        List<BasicConfigResp> list = basicConfigInfoService.selectBasicConfigInfoList(basicConfigInfo);
        ExcelUtil<BasicConfigResp> util = new ExcelUtil<BasicConfigResp>(BasicConfigResp.class);
        util.exportExcel(response, list, "基础信息数据");
    }

    /**
     * 获取基础信息详细信息
     */
    @RequiresPermissions("etl:info:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(basicConfigInfoService.selectBasicConfigInfoById(id));
    }

    /**
     * 新增基础信息
     */
    @RequiresPermissions("etl:info:add")
    @Log(title = "基础信息", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody BasicConfigInfo basicConfigInfo)
    {
        return toAjax(basicConfigInfoService.insertBasicConfigInfo(basicConfigInfo));
    }

    /**
     * 修改基础信息
     */
    @RequiresPermissions("etl:info:edit")
    @Log(title = "基础信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody BasicConfigInfo basicConfigInfo)
    {
        return toAjax(basicConfigInfoService.updateBasicConfigInfo(basicConfigInfo));
    }

    /**
     * 删除基础信息
     */
    @RequiresPermissions("etl:info:remove")
    @Log(title = "基础信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(basicConfigInfoService.deleteBasicConfigInfoByIds(ids));
    }
}
