package com.muyu.etl.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.etl.domain.BasicConfigInfo;
import com.muyu.etl.domain.BasicParams;
import com.muyu.etl.domain.resp.BasicConfigResp;
import com.muyu.etl.mapper.BasicConfigInfoMapper;
import com.muyu.etl.service.BasicConfigInfoService;
import com.muyu.etl.service.BasicParamsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * Service业务层处理
 *
 * @author muyu
 * @date 2024-04-20
 */
@Service
public class BasicConfigInfoServiceImpl  extends ServiceImpl<BasicConfigInfoMapper, BasicConfigInfo> implements BasicConfigInfoService
{
    @Autowired
    private BasicConfigInfoMapper basicConfigInfoMapper;
    @Autowired
    private BasicParamsService basicParamsService;

    /**
     * 查询
     *
     * @param id 主键
     * @return
     */
    @Override
    public BasicConfigInfo selectBasicConfigInfoById(Long id)
    {
        return basicConfigInfoMapper.selectBasicConfigInfoById(id);
    }

    /**
     * 查询列表
     *
     * @param basicConfigInfo
     * @return
     */
    @Override
    public List<BasicConfigResp> selectBasicConfigInfoList(BasicConfigInfo basicConfigInfo)
    {
        List<BasicConfigResp> basicConfigRespList = basicConfigInfoMapper.selectBasicConfigInfoList(basicConfigInfo).stream().map(
                info -> {
                    List<BasicParams> list = basicParamsService.list(new LambdaQueryWrapper<BasicParams>().eq(BasicParams::getBasicConfigInfoId, info.getId()));
                    StringBuffer buffer = new StringBuffer();
                    list.forEach(basicParam -> buffer.append("&"+basicParam.getParamsName()+"="+basicParam.getParamsValue()));
                    return BasicConfigResp.builder()
                            .id(info.getId())
                            .host(info.getHost())
                            .port(info.getPort())
                            .databaseName(info.getDatabaseName())
                            .databaseType(info.getDatabaseType())
                            .initLinkNum(info.getInitLinkNum())
                            .maxLinkNum(info.getMaxLinkNum())
                            .dataResourceName(info.getDataSourcesSystemName())
                            .dataSourcesSystemName(info.getDataSourcesSystemName())
                            .maxWaitTime(info.getMaxWaitTime())
                            .maxWaitTimes(info.getMaxWaitTimes())
                            .connectionParam(String.valueOf(buffer).substring(1))
                            .createBy(SecurityUtils.getUsername())
                            .createTime(new Date())
                            .remark(info.getRemark())
                            .build();
                }).collect(Collectors.toList());
        return basicConfigRespList;
    }

    /**
     * 新增
     *
     * @param basicConfigInfo
     * @return 结果
     */
    @Override
    public int insertBasicConfigInfo(BasicConfigInfo basicConfigInfo)
    {
        return basicConfigInfoMapper.insertBasicConfigInfo(basicConfigInfo);
    }

    /**
     * 修改
     *
     * @param basicConfigInfo
     * @return 结果
     */
    @Override
    public int updateBasicConfigInfo(BasicConfigInfo basicConfigInfo)
    {
        return basicConfigInfoMapper.updateBasicConfigInfo(basicConfigInfo);
    }

    /**
     * 批量删除
     *
     * @param ids 需要删除的主键
     * @return 结果
     */
    @Override
    public int deleteBasicConfigInfoByIds(Long[] ids)
    {
        return basicConfigInfoMapper.deleteBasicConfigInfoByIds(ids);
    }

    /**
     * 删除信息
     *
     * @param id 主键
     * @return 结果
     */
    @Override
    public int deleteBasicConfigInfoById(Long id)
    {
        return basicConfigInfoMapper.deleteBasicConfigInfoById(id);
    }
}
